@@ -1,4 +1,4 @@
-#include <libtracker-extract/tracker-extract.h>
+#include <tracker-common.h>
 
 G_MODULE_EXPORT gboolean
 tracker_extract_get_metadata (TrackerExtractInfo  *info,
